'use strict';

const request = require('request');

const config = require('komodo-sdk/config');
const logger = require('komodo-sdk/logger');

function incomingSMS(message) {
    if (!config || !config.report_url || !config.report_url.incoming_sms) return;

    const requestOptions = {
        url: config.report_url.incoming_sms,
        qs: {
            modem: config.name,
            ts: message.metadata.ts,
            status: message.metadata.status,
            number: message.metadata.from,
            msg: message.message,
        },
    };

    logger.info('Sending report via HTTP', requestOptions);
    request(requestOptions, (err, res, body) => {
        if (err) {
            logger.warn(`Error sending report via HTTP. ${err.toString()}`);
            return;
        }

        if (res.statusCode !== 200) {
            logger.warn(`Error sending report via HTTP. Server respond with HTTP status code ${res.statusCode}`, { http_status_code: res.statusCode, body });
        }
    });
}

exports.incomingSMS = incomingSMS;
